@@ -1,6 +1,6 @@
 
 
-#' Define sample kmeans clusters from taxa abundances.
+#' Cluster samples by taxa abundances k-means.
 #' 
 #' @inherit documentation_clusters
 #' @inherit documentation_default
@@ -26,7 +26,7 @@ taxa_clusters <- function (biom, rank = ".otu", k = 5, ...) {
 }
 
 
-#' Define sample PAM clusters from beta diversity.
+#' Cluster samples by beta diversity k-means.
 #' 
 #' @inherit documentation_clusters
 #' @inherit documentation_default
@@ -34,7 +34,7 @@ taxa_clusters <- function (biom, rank = ".otu", k = 5, ...) {
 #' @family beta_diversity
 #' @family clustering
 #' 
-#' @param ... Passed on to `cluster::pam()`.
+#' @param ... Passed on to `stats::kmeans()`.
 #' 
 #' @examples
 #'     library(rbiom)
@@ -46,7 +46,7 @@ taxa_clusters <- function (biom, rank = ".otu", k = 5, ...) {
 #'     
 #'     bdiv_ord_plot(biom, stat.by = "bray_cluster")
 
-bdiv_clusters <- function (biom, bdiv = "Bray-Curtis", weighted = TRUE, tree = NULL, k = 5, ...) {
-  dm <- bdiv_matrix(biom = biom, bdiv = bdiv, weighted = weighted, tree = tree)
-  factor(cluster::pam(dm, k = k, ...)$clustering)
+bdiv_clusters <- function (biom, bdiv = "Bray-Curtis", weighted = TRUE, normalized = TRUE, tree = NULL, k = 5, ...) {
+  dm <- bdiv_distmat(biom = biom, bdiv = bdiv, weighted = weighted, normalized = TRUE, tree = tree)
+  factor(stats::kmeans(dm, centers = k, ...)$cluster)
 }
